@@ -1,7 +1,7 @@
 #' Covert R^2 to S
 #'
 #' Converts R^2, the partial coefficient of determination, to
-#' robust effect size index (S) using the formula from Vandekar, Rao, & Blume (2020).
+#' robust effect size index (S) using the formula from Vandekar, Tao, & Blume (2020).
 #' @param Rsq Numeric, R^2
 #' @return Returns an estimate of R^2 based on the RESI
 #' @details The formula for the conversion is:
@@ -13,5 +13,16 @@
 #' # this corresponds to a RESI of 0.333
 #' @export
 Rsq2S <- function(Rsq){
-  sqrt((-Rsq)/(Rsq-1))
+  if (any(Rsq < 0 | Rsq > 1)){
+    stop("\nRsq must be between 0 and 1")
+  }
+  S = c()
+  for (i in 1:length(Rsq)){
+    if (Rsq[i] == 1){
+      S[i] = Inf
+    } else{
+      S[i] = sqrt((-Rsq[i])/(Rsq[i]-1))
+    }
+  }
+  return(S)
 }
